Coverage report

|  |  | Statements |  | Branches |  | Total
--- | --- | --- | --- | --- | --- | --- | ---
File | class |  | coverage | statements | missing | excluded |  | coverage | branches | partial |  | coverage
formkit_ninja / __init__.py | (no class) |  | 100% | 0 | 0 | 0 |  | 100% | 0 | 0 |  | 100%
formkit_ninja / __main__.py | (no class) |  | 100% | 0 | 0 | 0 |  | 100% | 0 | 0 |  | 100%
formkit_ninja / admin.py | ItemAdmin |  | 100% | 0 | 0 | 0 |  | 100% | 0 | 0 |  | 100%
formkit_ninja / admin.py | JSONMappingMixin |  | 0% | 48 | 48 | 0 |  | 0% | 32 | 0 |  | 0%
formkit_ninja / admin.py | FormKitBaseForm |  | 0% | 8 | 8 | 0 |  | 0% | 4 | 0 |  | 0%
formkit_ninja / admin.py | NewFormKitForm |  | 100% | 0 | 0 | 0 |  | 100% | 0 | 0 |  | 100%
formkit_ninja / admin.py | NewFormKitForm.Meta |  | 100% | 0 | 0 | 0 |  | 100% | 0 | 0 |  | 100%
formkit_ninja / admin.py | OptionForm |  | 100% | 0 | 0 | 0 |  | 100% | 0 | 0 |  | 100%
formkit_ninja / admin.py | OptionForm.Meta |  | 100% | 0 | 0 | 0 |  | 100% | 0 | 0 |  | 100%
formkit_ninja / admin.py | FormComponentsForm |  | 100% | 0 | 0 | 0 |  | 100% | 0 | 0 |  | 100%
formkit_ninja / admin.py | FormComponentsForm.Meta |  | 100% | 0 | 0 | 0 |  | 100% | 0 | 0 |  | 100%
formkit_ninja / admin.py | FormKitSchemaComponentInline |  | 100% | 0 | 0 | 0 |  | 100% | 0 | 0 |  | 100%
formkit_ninja / admin.py | FormKitNodeGroupForm |  | 100% | 0 | 0 | 0 |  | 100% | 0 | 0 |  | 100%
formkit_ninja / admin.py | FormKitNodeGroupForm.Meta |  | 100% | 0 | 0 | 0 |  | 100% | 0 | 0 |  | 100%
formkit_ninja / admin.py | FormKitNodeForm |  | 0% | 1 | 1 | 0 |  | 100% | 0 | 0 |  | 0%
formkit_ninja / admin.py | FormKitNodeForm.Meta |  | 100% | 0 | 0 | 0 |  | 100% | 0 | 0 |  | 100%
formkit_ninja / admin.py | FormKitNodeRepeaterForm |  | 0% | 1 | 1 | 0 |  | 100% | 0 | 0 |  | 0%
formkit_ninja / admin.py | FormKitTextNode |  | 100% | 0 | 0 | 0 |  | 100% | 0 | 0 |  | 100%
formkit_ninja / admin.py | FormKitTextNode.Meta |  | 100% | 0 | 0 | 0 |  | 100% | 0 | 0 |  | 100%
formkit_ninja / admin.py | FormKitElementForm |  | 100% | 0 | 0 | 0 |  | 100% | 0 | 0 |  | 100%
formkit_ninja / admin.py | FormKitElementForm.Meta |  | 100% | 0 | 0 | 0 |  | 100% | 0 | 0 |  | 100%
formkit_ninja / admin.py | FormKitConditionForm |  | 100% | 0 | 0 | 0 |  | 100% | 0 | 0 |  | 100%
formkit_ninja / admin.py | FormKitConditionForm.Meta |  | 100% | 0 | 0 | 0 |  | 100% | 0 | 0 |  | 100%
formkit_ninja / admin.py | FormKitComponentForm |  | 100% | 0 | 0 | 0 |  | 100% | 0 | 0 |  | 100%
formkit_ninja / admin.py | FormKitComponentForm.Meta |  | 100% | 0 | 0 | 0 |  | 100% | 0 | 0 |  | 100%
formkit_ninja / admin.py | NodeChildrenInline |  | 100% | 0 | 0 | 0 |  | 100% | 0 | 0 |  | 100%
formkit_ninja / admin.py | NodeParentsInline |  | 100% | 0 | 0 | 0 |  | 100% | 0 | 0 |  | 100%
formkit_ninja / admin.py | NodeInline |  | 100% | 0 | 0 | 0 |  | 100% | 0 | 0 |  | 100%
formkit_ninja / admin.py | SchemaLabelInline |  | 100% | 0 | 0 | 0 |  | 100% | 0 | 0 |  | 100%
formkit_ninja / admin.py | SchemaDescriptionInline |  | 100% | 0 | 0 | 0 |  | 100% | 0 | 0 |  | 100%
formkit_ninja / admin.py | FormKitSchemaForm |  | 100% | 0 | 0 | 0 |  | 100% | 0 | 0 |  | 100%
formkit_ninja / admin.py | FormKitSchemaForm.Meta |  | 100% | 0 | 0 | 0 |  | 100% | 0 | 0 |  | 100%
formkit_ninja / admin.py | FormKitSchemaNodeAdmin |  | 0% | 35 | 35 | 0 |  | 0% | 18 | 0 |  | 0%
formkit_ninja / admin.py | FormKitSchemaAdmin |  | 0% | 1 | 1 | 0 |  | 100% | 0 | 0 |  | 0%
formkit_ninja / admin.py | FormComponentsAdmin |  | 100% | 0 | 0 | 0 |  | 100% | 0 | 0 |  | 100%
formkit_ninja / admin.py | OptionLabelInline |  | 100% | 0 | 0 | 0 |  | 100% | 0 | 0 |  | 100%
formkit_ninja / admin.py | OptionInline |  | 100% | 0 | 0 | 0 |  | 100% | 0 | 0 |  | 100%
formkit_ninja / admin.py | OptionAdmin |  | 100% | 0 | 0 | 0 |  | 100% | 0 | 0 |  | 100%
formkit_ninja / admin.py | OptionGroupAdmin |  | 100% | 0 | 0 | 0 |  | 100% | 0 | 0 |  | 100%
formkit_ninja / admin.py | OptionLabelAdmin |  | 100% | 0 | 0 | 0 |  | 100% | 0 | 0 |  | 100%
formkit_ninja / admin.py | (no class) |  | 100% | 183 | 0 | 0 |  | 100% | 0 | 0 |  | 100%
formkit_ninja / api.py | FormKitSchemaIn |  | 100% | 0 | 0 | 0 |  | 100% | 0 | 0 |  | 100%
formkit_ninja / api.py | FormKitSchemaIn.Config |  | 100% | 0 | 0 | 0 |  | 100% | 0 | 0 |  | 100%
formkit_ninja / api.py | SchemaLabel |  | 100% | 0 | 0 | 0 |  | 100% | 0 | 0 |  | 100%
formkit_ninja / api.py | SchemaLabel.Config |  | 100% | 0 | 0 | 0 |  | 100% | 0 | 0 |  | 100%
formkit_ninja / api.py | SchemaDescription |  | 100% | 0 | 0 | 0 |  | 100% | 0 | 0 |  | 100%
formkit_ninja / api.py | SchemaDescription.Config |  | 100% | 0 | 0 | 0 |  | 100% | 0 | 0 |  | 100%
formkit_ninja / api.py | FormKitSchemaListOut |  | 100% | 0 | 0 | 0 |  | 100% | 0 | 0 |  | 100%
formkit_ninja / api.py | FormKitSchemaListOut.Config |  | 100% | 0 | 0 | 0 |  | 100% | 0 | 0 |  | 100%
formkit_ninja / api.py | FormComponentsOut |  | 100% | 0 | 0 | 0 |  | 100% | 0 | 0 |  | 100%
formkit_ninja / api.py | FormComponentsOut.Config |  | 100% | 0 | 0 | 0 |  | 100% | 0 | 0 |  | 100%
formkit_ninja / api.py | NodeChildrenOut |  | 100% | 0 | 0 | 0 |  | 100% | 0 | 0 |  | 100%
formkit_ninja / api.py | NodeChildrenOut.Config |  | 100% | 0 | 0 | 0 |  | 100% | 0 | 0 |  | 100%
formkit_ninja / api.py | NodeReturnType |  | 100% | 0 | 0 | 0 |  | 100% | 0 | 0 |  | 100%
formkit_ninja / api.py | NodeInactiveType |  | 100% | 0 | 0 | 0 |  | 100% | 0 | 0 |  | 100%
formkit_ninja / api.py | NodeStringType |  | 100% | 0 | 0 | 0 |  | 100% | 0 | 0 |  | 100%
formkit_ninja / api.py | Option |  | 100% | 0 | 0 | 0 |  | 100% | 0 | 0 |  | 100%
formkit_ninja / api.py | Option.Config |  | 100% | 0 | 0 | 0 |  | 100% | 0 | 0 |  | 100%
formkit_ninja / api.py | FormKitErrors |  | 100% | 0 | 0 | 0 |  | 100% | 0 | 0 |  | 100%
formkit_ninja / api.py | FormKitNodeIn |  | 0% | 31 | 31 | 0 |  | 0% | 16 | 0 |  | 0%
formkit_ninja / api.py | FormKitNodeIn.Config |  | 100% | 0 | 0 | 0 |  | 100% | 0 | 0 |  | 100%
formkit_ninja / api.py | (no class) |  | 62% | 229 | 87 | 0 |  | 3% | 36 | 1 |  | 54%
formkit_ninja / fields.py | WhitelistedKeysDict |  | 0% | 16 | 16 | 0 |  | 0% | 8 | 0 |  | 0%
formkit_ninja / fields.py | TranslatedValues |  | 0% | 12 | 12 | 0 |  | 0% | 10 | 0 |  | 0%
formkit_ninja / fields.py | TranslatedField |  | 0% | 4 | 4 | 0 |  | 100% | 0 | 0 |  | 0%
formkit_ninja / fields.py | (no class) |  | 92% | 24 | 2 | 0 |  | 50% | 2 | 1 |  | 88%
formkit_ninja / formkit_schema.py | FormKitSchemaCondition |  | 100% | 0 | 0 | 0 |  | 100% | 0 | 0 |  | 100%
formkit_ninja / formkit_schema.py | FormKitSchemaMeta |  | 100% | 0 | 0 | 0 |  | 100% | 0 | 0 |  | 100%
formkit_ninja / formkit_schema.py | FormKitTypeDefinition |  | 100% | 0 | 0 | 0 |  | 100% | 0 | 0 |  | 100%
formkit_ninja / formkit_schema.py | FormKitContextShape |  | 100% | 0 | 0 | 0 |  | 100% | 0 | 0 |  | 100%
formkit_ninja / formkit_schema.py | FormKitListValue |  | 100% | 0 | 0 | 0 |  | 100% | 0 | 0 |  | 100%
formkit_ninja / formkit_schema.py | FormKitListStatement |  | 100% | 0 | 0 | 0 |  | 100% | 0 | 0 |  | 100%
formkit_ninja / formkit_schema.py | FormKitSchemaAttributesCondition |  | 100% | 0 | 0 | 0 |  | 100% | 0 | 0 |  | 100%
formkit_ninja / formkit_schema.py | FormKitSchemaAttributesCondition.Config |  | 100% | 0 | 0 | 0 |  | 100% | 0 | 0 |  | 100%
formkit_ninja / formkit_schema.py | FormKitAttributeValue |  | 100% | 0 | 0 | 0 |  | 100% | 0 | 0 |  | 100%
formkit_ninja / formkit_schema.py | FormKitSchemaAttributes |  | 100% | 0 | 0 | 0 |  | 100% | 0 | 0 |  | 100%
formkit_ninja / formkit_schema.py | FormKitSchemaProps |  | 0% | 9 | 9 | 0 |  | 0% | 6 | 0 |  | 0%
formkit_ninja / formkit_schema.py | FormKitSchemaProps.Config |  | 100% | 0 | 0 | 0 |  | 100% | 0 | 0 |  | 100%
formkit_ninja / formkit_schema.py | TextNode |  | 100% | 0 | 0 | 0 |  | 100% | 0 | 0 |  | 100%
formkit_ninja / formkit_schema.py | TextAreaNode |  | 100% | 0 | 0 | 0 |  | 100% | 0 | 0 |  | 100%
formkit_ninja / formkit_schema.py | DateNode |  | 100% | 0 | 0 | 0 |  | 100% | 0 | 0 |  | 100%
formkit_ninja / formkit_schema.py | CurrencyNode |  | 100% | 0 | 0 | 0 |  | 100% | 0 | 0 |  | 100%
formkit_ninja / formkit_schema.py | UuidNode |  | 100% | 0 | 0 | 0 |  | 100% | 0 | 0 |  | 100%
formkit_ninja / formkit_schema.py | DatePickerNode |  | 100% | 0 | 0 | 0 |  | 100% | 0 | 0 |  | 100%
formkit_ninja / formkit_schema.py | CheckBoxNode |  | 100% | 0 | 0 | 0 |  | 100% | 0 | 0 |  | 100%
formkit_ninja / formkit_schema.py | NumberNode |  | 100% | 0 | 0 | 0 |  | 100% | 0 | 0 |  | 100%
formkit_ninja / formkit_schema.py | PasswordNode |  | 100% | 0 | 0 | 0 |  | 100% | 0 | 0 |  | 100%
formkit_ninja / formkit_schema.py | HiddenNode |  | 100% | 0 | 0 | 0 |  | 100% | 0 | 0 |  | 100%
formkit_ninja / formkit_schema.py | RadioNode |  | 100% | 0 | 0 | 0 |  | 100% | 0 | 0 |  | 100%
formkit_ninja / formkit_schema.py | SelectNode |  | 100% | 0 | 0 | 0 |  | 100% | 0 | 0 |  | 100%
formkit_ninja / formkit_schema.py | AutocompleteNode |  | 100% | 0 | 0 | 0 |  | 100% | 0 | 0 |  | 100%
formkit_ninja / formkit_schema.py | EmailNode |  | 100% | 0 | 0 | 0 |  | 100% | 0 | 0 |  | 100%
formkit_ninja / formkit_schema.py | TelNode |  | 100% | 0 | 0 | 0 |  | 100% | 0 | 0 |  | 100%
formkit_ninja / formkit_schema.py | DropDownNode |  | 100% | 0 | 0 | 0 |  | 100% | 0 | 0 |  | 100%
formkit_ninja / formkit_schema.py | RepeaterNode |  | 100% | 0 | 0 | 0 |  | 100% | 0 | 0 |  | 100%
formkit_ninja / formkit_schema.py | GroupNode |  | 100% | 0 | 0 | 0 |  | 100% | 0 | 0 |  | 100%
formkit_ninja / formkit_schema.py | FormKitSchemaDOMNode |  | 100% | 0 | 0 | 0 |  | 100% | 0 | 0 |  | 100%
formkit_ninja / formkit_schema.py | FormKitSchemaDOMNode.Config |  | 100% | 0 | 0 | 0 |  | 100% | 0 | 0 |  | 100%
formkit_ninja / formkit_schema.py | FormKitSchemaComponent |  | 100% | 0 | 0 | 0 |  | 100% | 0 | 0 |  | 100%
formkit_ninja / formkit_schema.py | FormKitSchemaComponent.Config |  | 100% | 0 | 0 | 0 |  | 100% | 0 | 0 |  | 100%
formkit_ninja / formkit_schema.py | FormKitTagParser |  | 0% | 23 | 23 | 0 |  | 0% | 10 | 0 |  | 0%
formkit_ninja / formkit_schema.py | Discriminators |  | 100% | 0 | 0 | 0 |  | 100% | 0 | 0 |  | 100%
formkit_ninja / formkit_schema.py | FormKitNode |  | 0% | 40 | 40 | 0 |  | 0% | 20 | 0 |  | 0%
formkit_ninja / formkit_schema.py | FormKitSchema |  | 0% | 6 | 6 | 0 |  | 0% | 2 | 0 |  | 0%
formkit_ninja / formkit_schema.py | (no class) |  | 95% | 201 | 10 | 0 |  | 17% | 12 | 0 |  | 91%
formkit_ninja / management / __init__.py | (no class) |  | 100% | 0 | 0 | 0 |  | 100% | 0 | 0 |  | 100%
formkit_ninja / management / commands / __init__.py | (no class) |  | 100% | 0 | 0 | 0 |  | 100% | 0 | 0 |  | 100%
formkit_ninja / management / commands / check_valid_names.py | Command |  | 0% | 7 | 7 | 0 |  | 0% | 4 | 0 |  | 0%
formkit_ninja / management / commands / check_valid_names.py | (no class) |  | 0% | 6 | 6 | 0 |  | 100% | 0 | 0 |  | 0%
formkit_ninja / management / commands / import_forms.py | Command |  | 0% | 11 | 11 | 0 |  | 0% | 2 | 0 |  | 0%
formkit_ninja / management / commands / import_forms.py | (no class) |  | 0% | 7 | 7 | 0 |  | 100% | 0 | 0 |  | 0%
formkit_ninja / models.py | UuidIdModel |  | 100% | 0 | 0 | 0 |  | 100% | 0 | 0 |  | 100%
formkit_ninja / models.py | UuidIdModel.Meta |  | 100% | 0 | 0 | 0 |  | 100% | 0 | 0 |  | 100%
formkit_ninja / models.py | OptionDict |  | 100% | 0 | 0 | 0 |  | 100% | 0 | 0 |  | 100%
formkit_ninja / models.py | OptionGroup |  | 0% | 16 | 16 | 0 |  | 0% | 6 | 0 |  | 0%
formkit_ninja / models.py | OptionQuerySet |  | 0% | 5 | 5 | 0 |  | 100% | 0 | 0 |  | 0%
formkit_ninja / models.py | Option |  | 0% | 15 | 15 | 0 |  | 0% | 8 | 0 |  | 0%
formkit_ninja / models.py | Option.Meta |  | 100% | 0 | 0 | 0 |  | 100% | 0 | 0 |  | 100%
formkit_ninja / models.py | OptionLabel |  | 0% | 3 | 3 | 0 |  | 0% | 2 | 0 |  | 0%
formkit_ninja / models.py | OptionLabel.Meta |  | 100% | 0 | 0 | 0 |  | 100% | 0 | 0 |  | 100%
formkit_ninja / models.py | FormComponents |  | 0% | 1 | 1 | 0 |  | 100% | 0 | 0 |  | 0%
formkit_ninja / models.py | FormComponents.Meta |  | 100% | 0 | 0 | 0 |  | 100% | 0 | 0 |  | 100%
formkit_ninja / models.py | NodeChildrenManager |  | 0% | 4 | 4 | 0 |  | 0% | 2 | 0 |  | 0%
formkit_ninja / models.py | NodeChildren |  | 100% | 0 | 0 | 0 |  | 100% | 0 | 0 |  | 100%
formkit_ninja / models.py | NodeChildren.Meta |  | 100% | 0 | 0 | 0 |  | 100% | 0 | 0 |  | 100%
formkit_ninja / models.py | NodeQS |  | 0% | 11 | 11 | 0 |  | 0% | 6 | 0 |  | 0%
formkit_ninja / models.py | FormKitSchemaNode |  | 0% | 175 | 175 | 0 |  | 0% | 142 | 0 |  | 0%
formkit_ninja / models.py | SchemaManager |  | 100% | 1 | 0 | 0 |  | 100% | 0 | 0 |  | 100%
formkit_ninja / models.py | FormKitSchema |  | 0% | 17 | 17 | 0 |  | 0% | 4 | 0 |  | 0%
formkit_ninja / models.py | SchemaLabel |  | 100% | 0 | 0 | 0 |  | 100% | 0 | 0 |  | 100%
formkit_ninja / models.py | SchemaDescription |  | 100% | 0 | 0 | 0 |  | 100% | 0 | 0 |  | 100%
formkit_ninja / models.py | (no class) |  | 95% | 156 | 8 | 0 |  | 0% | 8 | 0 |  | 90%
formkit_ninja / parser / __init__.py | (no class) |  | 100% | 0 | 0 | 0 |  | 100% | 0 | 0 |  | 100%
formkit_ninja / parser / logger.py | (no class) |  | 0% | 3 | 3 | 0 |  | 100% | 0 | 0 |  | 0%
formkit_ninja / parser / type_convert.py | NodePath |  | 0% | 143 | 143 | 0 |  | 0% | 92 | 0 |  | 0%
formkit_ninja / parser / type_convert.py | (no class) |  | 87% | 97 | 13 | 0 |  | 0% | 8 | 0 |  | 80%
formkit_ninja / samples / __init__.py | (no class) |  | 100% | 0 | 0 | 0 |  | 100% | 0 | 0 |  | 100%
formkit_ninja / schemas / __init__.py | Schemas |  | 33% | 12 | 8 | 0 |  | 0% | 2 | 0 |  | 29%
formkit_ninja / schemas / __init__.py | (no class) |  | 100% | 12 | 0 | 0 |  | 100% | 0 | 0 |  | 100%
formkit_ninja / schemas / schemas.py | (no class) |  | 100% | 0 | 0 | 0 |  | 100% | 0 | 0 |  | 100%
formkit_ninja / triggers.py | (no class) |  | 82% | 17 | 3 | 0 |  | 100% | 0 | 0 |  | 82%
formkit_ninja / urls.py | (no class) |  | 0% | 6 | 6 | 0 |  | 100% | 0 | 0 |  | 0%
Total |  |  | 50% | 1597 | 796 | 0 |  | 1% | 462 | 2 |  | 39%

No items found using the specified filter.